@@ -26,7 +26,8 @@ class AccountResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def reopen_account(self, account_id: str, reason: str = "ByCustomer") -> Union[UnitResponse[AccountDTO], UnitError]:
+    def reopen_account(self, account_id: str, reason: AccountCloseReason = "ByCustomer") ->\
+            Union[UnitResponse[AccountDTO], UnitError]:
         response = super().post(f"{self.resource}/{account_id}/reopen", {'reason': reason})
         if super().is_20x(response.status_code):
             data = response.json().get("data")
@@ -67,7 +68,6 @@ class AccountResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-
     def get(self, account_id: str, include: Optional[str] = "") -> Union[UnitResponse[AccountDTO], UnitError]:
         response = super().get(f"{self.resource}/{account_id}", {"include": include})
         if super().is_20x(response.status_code):
@@ -128,6 +128,4 @@ class AccountResource(BaseResource):
             data = response.json().get("data")
             return UnitResponse[AccountDTO](DtoDecoder.decode(data), None)
         else:
-            return UnitError.from_json_api(response.json())
-
-
+            return UnitError.from_json_api(response.json())
\ No newline at end of file
